package VMOMI::HostStandbyMode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
